@@ -96,10 +96,10 @@ def get_server_version(url):
 
 
 def get_highest_client_server_version(url):
+    """Returns highest supported version by client and server as a string."""
     min_server, max_server = get_server_version(url)
-    max_server_version = api_versions.APIVersion.get_string(max_server)
-
-    return min(float(max_server_version), float(api_versions.MAX_VERSION))
+    max_client = api_versions.APIVersion(api_versions.MAX_VERSION)
+    return min(max_server, max_client).get_string()
 
 
 def get_volume_api_from_url(url):
@@ -126,12 +126,10 @@ def _log_request_id(logger, resp, service_name):
 
 
 class SessionClient(adapter.LegacyJsonAdapter):
-    global_request_id = None
 
     def __init__(self, *args, **kwargs):
         self.api_version = kwargs.pop('api_version', None)
         self.api_version = self.api_version or api_versions.APIVersion()
-        self.global_request_id = kwargs.pop('global_request_id', None)
         self.retries = kwargs.pop('retries', 0)
         self._logger = logging.getLogger(__name__)
         super(SessionClient, self).__init__(*args, **kwargs)
@@ -141,9 +139,6 @@ class SessionClient(adapter.LegacyJsonAdapter):
         api_versions.update_headers(kwargs["headers"], self.api_version)
         kwargs.setdefault('authenticated', False)
 
-        if self.global_request_id:
-            kwargs['headers'].setdefault(REQ_ID_HEADER, self.global_request_id)
-
         # Note(tpatil): The standard call raises errors from
         # keystoneauth, here we need to raise the cinderclient errors.
         raise_exc = kwargs.pop('raise_exc', True)
