@@ -67,7 +67,6 @@ from cinderclient.v2 import availability_zones
            help='Filters results by a migration status. Default=None. '
                 'Admin only.')
 @utils.arg('--metadata',
-           type=str,
            nargs='*',
            metavar='<key=value>',
            default=None,
@@ -272,7 +271,6 @@ class CheckSizeArgForCreate(argparse.Action):
 @utils.arg('--availability_zone',
            help=argparse.SUPPRESS)
 @utils.arg('--metadata',
-           type=str,
            nargs='*',
            metavar='<key=value>',
            default=None,
@@ -345,47 +343,6 @@ def do_create(cs, args):
     utils.print_dict(info)
 
 
-@utils.arg('volume',
-           metavar='<volume>',
-           help='Name or ID of volume to snapshot.')
-@utils.arg('--force',
-           metavar='<True|False>',
-           const=True,
-           nargs='?',
-           default=False,
-           help='Enables or disables upload of '
-           'a volume that is attached to an instance. '
-           'Default=False. '
-           'This option may not be supported by your cloud.')
-@utils.arg('--container-format',
-           metavar='<container-format>',
-           default='bare',
-           help='Container format type. '
-                'Default is bare.')
-@utils.arg('--container_format',
-           help=argparse.SUPPRESS)
-@utils.arg('--disk-format',
-           metavar='<disk-format>',
-           default='raw',
-           help='Disk format type. '
-                'Default is raw.')
-@utils.arg('--disk_format',
-           help=argparse.SUPPRESS)
-@utils.arg('image_name',
-           metavar='<image-name>',
-           help='The new image name.')
-@utils.arg('--image_name',
-           help=argparse.SUPPRESS)
-def do_upload_to_image(cs, args):
-    """Uploads volume to Image Service as an image."""
-    volume = utils.find_volume(cs, args.volume)
-    shell_utils.print_volume_image(
-        volume.upload_to_image(args.force,
-                               args.image_name,
-                               args.container_format,
-                               args.disk_format))
-
-
 @utils.arg('--cascade',
            action='store_true',
            default=False,
@@ -684,7 +641,6 @@ def do_snapshot_show(cs, args):
 @utils.arg('--display_description',
            help=argparse.SUPPRESS)
 @utils.arg('--metadata',
-           type=str,
            nargs='*',
            metavar='<key=value>',
            default=None,
@@ -761,6 +717,8 @@ def do_snapshot_rename(cs, args):
         raise exceptions.ClientException(code=1, message=msg)
 
     shell_utils.find_volume_snapshot(cs, args.snapshot).update(**kwargs)
+    print("Request to rename snapshot '%s' has been accepted." % (
+        args.snapshot))
 
 
 @utils.arg('snapshot', metavar='<snapshot>', nargs='+',
@@ -1020,10 +978,6 @@ def do_quota_defaults(cs, args):
            metavar='<backup_gigabytes>',
            type=int, default=None,
            help='The new "backup_gigabytes" quota value. Default=None.')
-@utils.arg('--consistencygroups',
-           metavar='<consistencygroups>',
-           type=int, default=None,
-           help='The new "consistencygroups" quota value. Default=None.')
 @utils.arg('--volume-type',
            metavar='<volume_type_name>',
            default=None,
@@ -1070,10 +1024,22 @@ def do_quota_class_show(cs, args):
            metavar='<gigabytes>',
            type=int, default=None,
            help='The new "gigabytes" quota value. Default=None.')
+@utils.arg('--backups',
+           metavar='<backups>',
+           type=int, default=None,
+           help='The new "backups" quota value. Default=None.')
+@utils.arg('--backup-gigabytes',
+           metavar='<backup_gigabytes>',
+           type=int, default=None,
+           help='The new "backup_gigabytes" quota value. Default=None.')
 @utils.arg('--volume-type',
            metavar='<volume_type_name>',
            default=None,
            help='Volume type. Default=None.')
+@utils.arg('--per-volume-gigabytes',
+           metavar='<per_volume_gigabytes>',
+           type=int, default=None,
+           help='Set max volume size limit. Default=None.')
 def do_quota_class_update(cs, args):
     """Updates quotas for a quota class."""
 
@@ -1429,6 +1395,7 @@ def do_backup_reset_state(cs, args):
     for backup in args.backup:
         try:
             shell_utils.find_backup(cs, backup).reset_state(args.state)
+            print("Request to update backup '%s' has been accepted." % backup)
         except Exception as e:
             failure_count += 1
             msg = "Reset state for backup %s failed: %s" % (backup, e)
@@ -1685,14 +1652,19 @@ def do_encryption_type_show(cs, args):
            default=None,
            help='The encryption algorithm or mode. '
                 'For example, aes-xts-plain64. Default=None.')
-@utils.arg('--key_size',
+@utils.arg('--key-size',
            metavar='<key_size>',
            type=int,
            required=False,
            default=None,
            help='Size of encryption key, in bits. '
                 'For example, 128 or 256. Default=None.')
-@utils.arg('--control_location',
+@utils.arg('--key_size',
+           type=int,
+           required=False,
+           default=None,
+           help=argparse.SUPPRESS)
+@utils.arg('--control-location',
            metavar='<control_location>',
            choices=['front-end', 'back-end'],
            type=str,
@@ -1701,6 +1673,11 @@ def do_encryption_type_show(cs, args):
            help='Notional service where encryption is performed. '
                 'Valid values are "front-end" or "back-end." '
                 'For example, front-end=Nova. Default is "front-end."')
+@utils.arg('--control_location',
+           type=str,
+           required=False,
+           default='front-end',
+           help=argparse.SUPPRESS)
 def do_encryption_type_create(cs, args):
     """Creates encryption type for a volume type. Admin only."""
     volume_type = shell_utils.find_volume_type(cs, args.volume_type)
@@ -1725,8 +1702,7 @@ def do_encryption_type_create(cs, args):
            type=str,
            required=False,
            default=argparse.SUPPRESS,
-           help="Class providing encryption support (e.g. LuksEncryptor) "
-           "(Optional)")
+           help="Class providing encryption support (e.g. LuksEncryptor)")
 @utils.arg('--cipher',
            metavar='<cipher>',
            type=str,
@@ -1735,8 +1711,7 @@ def do_encryption_type_create(cs, args):
            default=argparse.SUPPRESS,
            const=None,
            help="Encryption algorithm/mode to use (e.g., aes-xts-plain64). "
-           "Provide parameter without value to set to provider default. "
-           "(Optional)")
+           "Provide parameter without value to set to provider default.")
 @utils.arg('--key-size',
            dest='key_size',
            metavar='<key-size>',
@@ -1746,8 +1721,7 @@ def do_encryption_type_create(cs, args):
            default=argparse.SUPPRESS,
            const=None,
            help="Size of the encryption key, in bits (e.g., 128, 256). "
-           "Provide parameter without value to set to provider default. "
-           "(Optional)")
+           "Provide parameter without value to set to provider default. ")
 @utils.arg('--control-location',
            dest='control_location',
            metavar='<control-location>',
@@ -1756,7 +1730,7 @@ def do_encryption_type_create(cs, args):
            required=False,
            default=argparse.SUPPRESS,
            help="Notional service where encryption is performed (e.g., "
-           "front-end=Nova). Values: 'front-end', 'back-end' (Optional)")
+           "front-end=Nova). Values: 'front-end', 'back-end'")
 def do_encryption_type_update(cs, args):
     """Update encryption type information for a volume type (Admin Only)."""
     volume_type = shell_utils.find_volume_type(cs, args.volume_type)
@@ -2020,7 +1994,6 @@ def do_set_bootable(cs, args):
            metavar='<availability-zone>',
            help='Availability zone for volume (Default=None)')
 @utils.arg('--metadata',
-           type=str,
            nargs='*',
            metavar='<key=value>',
            help='Metadata key=value pairs (Default=None)')
@@ -2262,6 +2235,8 @@ def do_consisgroup_update(cs, args):
 
     shell_utils.find_consistencygroup(
         cs, args.consistencygroup).update(**kwargs)
+    print("Request to update consistency group '%s' has been accepted." % (
+        args.consistencygroup))
 
 
 @utils.arg('--all-tenants',
@@ -2406,7 +2381,6 @@ def do_get_capabilities(cs, args):
            metavar='<description>',
            help='Snapshot description (Default=None)')
 @utils.arg('--metadata',
-           type=str,
            nargs='*',
            metavar='<key=value>',
            help='Metadata key=value pairs (Default=None)')
